@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK @EXPORT);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 #----------------------------------------------------------------------------
 
@@ -514,16 +514,42 @@ other modules.
 
 =head1 SEE ALSO
 
-  Calendar::Functions
+=head2 Further Modules
 
-  Clone
-  Date::ICal
-  DateTime
-  Time::Local
-  Time::Piece
+=over 4
 
-  The Calendar FAQ at http://www.tondering.dk/claus/calendar.html
+=item L<Calendar::Functions>
 
+=back
+
+=head2 Date/Time Modules
+
+=over 4
+
+=item L<Date::ICal>
+
+=item L<DateTime>
+
+=item L<Time::Local>
+
+=item L<Time::Piece>
+
+=back
+
+=head2 Further Information
+
+=over 4
+
+=item L<The Calendar FAQ>
+
+L<http://www.tondering.dk/claus/calendar.html>
+
+=item L<The Perl Advent Entry>
+
+2018-12-01 : L<http://perladvent.org/2018/2018-12-01.html>
+
+=back
+  
 =head1 BUGS, PATCHES & FIXES
 
 There are no known bugs at the time of this release. However, if you spot a
